Coverage for src\derivepassphrase\__init__.py: 100.000%

1# SPDX-FileCopyrightText: 2025 Marco Ricci <software@the13thletter.info>

2#

3# SPDX-License-Identifier: Zlib

4

5"""Work-alike of vault(1) – a deterministic, stateless password manager""" # noqa: D415,RUF002

6

7 __author__ = 'Marco Ricci <software@the13thletter.info>' (empty)

8 __distribution_name__ = 'derivepassphrase' (empty)

9

10# Automatically generated. DO NOT EDIT! Use importlib.metadata instead

11# to query the correct values.

12 __version__ = '0.5a1.dev1' (empty)

13# END automatically generated.